@@ -1,11 +1,7 @@
-from __future__ import unicode_literals
-
 import logging
 import os
 import re
 
-from django.utils.six import string_types
-
 from sorl.thumbnail.conf import settings, defaults as default_settings
 from sorl.thumbnail.helpers import tokey, serialize
 from sorl.thumbnail.images import ImageFile, DummyImageFile
@@ -23,7 +19,7 @@ EXTENSIONS = {
 }
 
 
-class ThumbnailBackend(object):
+class ThumbnailBackend:
     """
     The main class for sorl-thumbnail, you can subclass this if you for example
     want to change the way destination filename is generated.
@@ -106,13 +102,13 @@ class ThumbnailBackend(object):
         if settings.THUMBNAIL_FORCE_OVERWRITE or not thumbnail.exists():
             try:
                 source_image = default.engine.get_image(source)
-            except IOError as e:
+            except Exception as e:
                 logger.exception(e)
                 if settings.THUMBNAIL_DUMMY:
                     return DummyImageFile(geometry_string)
                 else:
-                    # if S3Storage says file doesn't exist remotely, don't try to
-                    # create it and exit early.
+                    # if storage backend says file doesn't exist remotely,
+                    # don't try to create it and exit early.
                     # Will return working empty image type; 404'd image
                     logger.warning(
                         'Remote file [%s] at [%s] does not exist',
@@ -179,10 +175,10 @@ class ThumbnailBackend(object):
         for resolution in settings.THUMBNAIL_ALTERNATIVE_RESOLUTIONS:
             resolution_geometry = (int(geometry[0] * resolution), int(geometry[1] * resolution))
             resolution_options = options.copy()
-            if 'crop' in options and isinstance(options['crop'], string_types):
+            if 'crop' in options and isinstance(options['crop'], str):
                 crop = options['crop'].split(" ")
                 for i in range(len(crop)):
-                    s = re.match("(\d+)px", crop[i])
+                    s = re.match(r"(\d+)px", crop[i])
                     if s:
                         crop[i] = "%spx" % int(int(s.group(1)) * resolution)
                 resolution_options['crop'] = " ".join(crop)
