@@ -1,18 +1,17 @@
-# encoding=utf-8
-
-from __future__ import unicode_literals, division
 import json
 import os
+import platform
 import re
+from urllib.error import URLError
+from urllib.parse import quote, quote_plus, urlsplit, urlunsplit
+from urllib.request import urlopen, Request
 
 from django.core.files.base import File, ContentFile
 from django.core.files.storage import Storage  # , default_storage
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils.encoding import force_str
 from django.utils.functional import LazyObject, empty
 from sorl.thumbnail import default
 from sorl.thumbnail.conf import settings
-from sorl.thumbnail.compat import (urlopen, urlparse, urlsplit,
-                                   quote, quote_plus, URLError, encode)
 from sorl.thumbnail.default import storage as default_storage
 from sorl.thumbnail.helpers import ThumbnailError, tokey, get_module_class, deserialize
 from sorl.thumbnail.parsers import parse_geometry
@@ -44,7 +43,7 @@ def deserialize_image_file(s):
     return image_file
 
 
-class BaseImageFile(object):
+class BaseImageFile:
     size = []
 
     def exists(self):
@@ -76,7 +75,6 @@ class BaseImageFile(object):
     src = url
 
 
-@python_2_unicode_compatible
 class ImageFile(BaseImageFile):
     _size = None
 
@@ -88,7 +86,7 @@ class ImageFile(BaseImageFile):
         if hasattr(file_, 'name'):
             self.name = file_.name
         else:
-            self.name = force_text(file_)
+            self.name = force_str(file_)
 
         # TODO: Add a customizable naming method as a signal
 
@@ -216,17 +214,23 @@ class DummyImageFile(BaseImageFile):
 
 
 class UrlStorage(Storage):
-    def normalize_url(self, url, charset='utf-8'):
-        url = encode(url, charset, 'ignore')
+    def normalize_url(self, url, charset="utf-8"):
+        # Convert URL to ASCII before processing
+        url = url.encode(charset, errors="ignore")
+        url = url.decode("ascii", errors="ignore")
         scheme, netloc, path, qs, anchor = urlsplit(url)
 
-        path = quote(path, b'/%')
-        qs = quote_plus(qs, b':&%=')
+        path = quote(path, b"/%")
+        qs = quote_plus(qs, b":&%=")
 
-        return urlparse.urlunsplit((scheme, netloc, path, qs, anchor))
+        return urlunsplit((scheme, netloc, path, qs, anchor))
 
     def open(self, name, mode='rb'):
-        return urlopen(self.normalize_url(name))
+        url = self.normalize_url(name)
+        python_version = platform.python_version_tuple()[0]
+        user_agent = "python-urllib{python_version}/0.6".format(python_version=python_version)
+        req = Request(url, headers={"User-Agent": user_agent})
+        return urlopen(req, timeout=settings.THUMBNAIL_URL_TIMEOUT)
 
     def exists(self, name):
         try:
