@@ -111,8 +111,10 @@ class TemplateTestCaseA(BaseTestCase):
             exif = im._getexif()
 
             # no exif editor in GraphicsMagick
-            if exif and not (settings.THUMBNAIL_CONVERT.endswith('gm convert') or
-                             'pgmagick_engine' in settings.THUMBNAIL_ENGINE):
+            if exif and not (
+                settings.THUMBNAIL_CONVERT.endswith('gm convert')
+                or 'pgmagick_engine' in settings.THUMBNAIL_ENGINE
+            ):
                 self.assertEqual(exif.get(0x0112), 1)
 
 
@@ -123,11 +125,11 @@ class TemplateTestCaseB(BaseTestCase):
 
     def test_portrait(self):
         val = render_to_string('thumbnail4.html', {
-            'source': 'http://dummyimage.com/120x100/',
+            'source': 'https://dummyimage.com/120x100/',
             'dims': 'x66',
         }).strip()
         self.assertEqual(val,
-                         '<img src="/media/test/cache/7b/cd/7bcd20922c6750649f431df7c3cdbc5e.jpg" '
+                         '<img src="/media/test/cache/82/62/8262858c5f95f2bd7715d7aaa3e52b11.jpg" '
                          'width="79" height="66" class="landscape">')
 
     def test_empty(self):
